#!/usr/bin/env node
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs-extra");
const globby = require("globby");
const meow = require("meow");
const path = require("path");
const transform_1 = require("./transform");
function main(cli) {
    return __awaiter(this, void 0, void 0, function* () {
        if (cli.flags.h) {
            cli.showHelp(0);
            return;
        }
        const cwd = process.cwd();
        const makeRelative = (x) => path.resolve(cwd, x);
        const transformPaths = [].concat(cli.flags['t'] || [], cli.flags['transform'] || []).map(makeRelative);
        const transforms = transformPaths.map(filepath => require(filepath).default);
        const paths = yield globby(cli.input);
        paths.forEach((filepath) => __awaiter(this, void 0, void 0, function* () {
            const source = (yield fs.readFile(filepath)).toString();
            const result = transform_1.applyTransforms(filepath, source, transforms);
            if (result !== source && !cli.flags.d && !cli.flags.dry) {
                yield fs.writeFile(filepath, result);
            }
            if (cli.flags.print || cli.flags.p) {
                console.log(`Output for ${filepath}`);
                console.log(result);
            }
        }));
    });
}
const cli = meow(`
  Usage: tscodeshift <path>... [options]

  path     Files or directory to transform

  Options:
    -t FILE, --transform FILE   Path to the transform file. Can be either a local path or url  [./transform.js]
    -d, --dry                   Dry run (no changes are made to files)
    -p, --print                 Print output, useful for development
`);
main(cli)
    .catch(e => {
    console.log('Failed to run tscodeshift.', e, e.stack);
    process.exit(1);
});
